@@ -55,7 +55,7 @@ from os import path
 # (https://docs.python.org/3.7/library/socket.html#module-socket)
 from socket import gethostname
 
-if str(gethostname()) == "mh3" or str(gethostname()) == "M-iMac142":
+if str(gethostname()) in {"mh3", "M-iMac142"}:
     # Module "pymysql": Python MySQL client library
     # (https://pypi.org/project/PyMySQL)
     # Using "pymysql" instead of MySQLdb which is limited to python2.7
@@ -218,39 +218,37 @@ def database_read(def_mysql_const,
         return "error"
 
 
-def read_config(_config_filename, _program_name, _log_filename, _hostname):
+def read_config(def_config_filename, def_program_name, def_log_filename, def_hostname):
     """
     Reads the configuration file.
-    :param _config_filename: str, name of the configuration file
-    :param _program_name: str, name of this program
-    :param _log_filename: str, name of the logfile
-    :param _hostname: str, name of the host machine
+    :param def_config_filename: str, name of the configuration file
+    :param def_program_name: str, name of this program
+    :param def_log_filename: str, name of the logfile
+    :param def_hostname: str, name of the host machine
     :returns: the configuration files object
     """
 
-    module_logger.info("Configuration file: loading...")
-    if not path.isfile(_config_filename):
-        module_logger.critical("Program stopped: no configuration file found (expected is: '" +
-                               _config_filename + "')")
-        exit_critical(_program_name, _log_filename, _hostname)
+    if not path.isfile(def_config_filename):
+        module_logger.critical(f"Program stopped: no configuration file found (expected is: '{def_config_filename}')")
+        exit_critical(def_program_name, def_log_filename, def_hostname)
     config = ConfigParser()
     config.optionxform = str
-    config.read(_config_filename)
+    config.read(def_config_filename)
+    module_logger.info(f"Configuration file '{def_config_filename}' was read.")
     return config
 
 
-def exit_critical(_program_name, _log_filename, _hostname):
+def exit_critical(def_program_name, def_log_filename, def_hostname):
     """
     Stops the program with a message to the console.
-    :param _program_name: str, name of this program
-    :param _log_filename: str, name of the logfile
-    :param _hostname: str, name of the host machine
+    :param def_program_name: str, name of this program
+    :param def_log_filename: str, name of the logfile
+    :param def_hostname: str, name of the host machine
     :returns: None
     """
 
-    print(_program_name + " (@" + _hostname +
-          "): CRITICAL: Program stopped - check logfile: '" +
-          _log_filename + "'" + " (timestamp = " + str(datetime.now().strftime("%Y-%m-%d %H:%M:%S")) + ")")
+    print(f"{def_program_name} (@{def_hostname}): CRITICAL: Program stopped - check logfile: '{def_log_filename}' "
+          f"(timestamp = {str(datetime.now().strftime('%Y-%m-%d %H:%M:%S'))})")
     exit()
 
 
@@ -261,10 +259,10 @@ def send_telegram_message(telegram_active, telegram_program, telegram_recipient_
     :param telegram_active: str, whether telegram sending shall be active, can be "YES" or "NO"
     :param telegram_program: str, path to the telegram script
     :param telegram_recipient_dict: dict, contains the dict of keywords and telegram recipients
-    :param telegram_message_address: str, contains the keyword which defines the recipients of the telegram message_text
+    :param telegram_message_address: str, contains the keyword which defines the recipients of the telegram message
     :param telegram_message: str, message_text to be send via telegram
     :param telegram_picture: str, path to picture to be send via telegram
-    :returns: bool, whether the telegram message_text was send
+    :returns: bool, whether the telegram message_text was successfully send
     """
 
     def send_telegram_message_function(_telegram_active, _telegram_program, _telegram_recipient_dict,
